lilypondfiletools.BookpartBlock
===============================

.. abjad-lineage:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock

.. autoclass:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.append
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.count
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.extend
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.index
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.insert
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.is_formatted_when_empty
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.pop
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.remove
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.reverse
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.sort
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__add__
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__contains__
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__delitem__
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__delslice__
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__eq__
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__format__
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__ge__
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__getitem__
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__getslice__
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__gt__
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__iadd__
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__imul__
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__iter__
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__le__
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__len__
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__lt__
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__mul__
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__ne__
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__repr__
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__reversed__
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__rmul__
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__setitem__
      ~abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__setslice__

Bases
-----

- :py:class:`lilypondfiletools.NonattributedBlock <abjad.tools.lilypondfiletools.NonattributedBlock.NonattributedBlock>`

- :py:class:`__builtin__.list <list>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read/write properties
---------------------

.. autoattribute:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.is_formatted_when_empty
   :noindex:

Methods
-------

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.append
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.count
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.extend
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.index
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.insert
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.pop
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.remove
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.reverse
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.sort
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__add__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__contains__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__delitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__delslice__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__format__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__ge__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__getitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__getslice__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__gt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__iadd__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__imul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__iter__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__le__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__len__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__lt__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__mul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__repr__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__reversed__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__rmul__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__setitem__
   :noindex:

.. automethod:: abjad.tools.lilypondfiletools.BookpartBlock.BookpartBlock.__setslice__
   :noindex:
